@@ -1,5 +1,8 @@
 import sys
 import linecache
+from baidufanyi import BaiduFanyi
+
+fanyi = BaiduFanyi("20220528001231583", "eMc9x1hxvUtJRLY97DKA")
 
 def my_excepthook(exctype, value, tb):
     print("[cxw] 阿 门 ~ 你的程序又报错了！")
@@ -30,7 +33,8 @@ def my_excepthook(exctype, value, tb):
         err_msg = "你用Ctrl-C终止了程序！"
     print(msg + err_msg)
     print(exctype.__name__ + ": " + str(value))
-
+    print("错误详情的百度翻译：")
+    print(fanyi.translate(err_msg))
 
 sys.excepthook = my_excepthook
 
